@@ -6,7 +6,11 @@ echo
 export PATH=/usr/bin:/usr/sbin:/bin:$PATH
 touch NEWS README AUTHORS ChangeLog stamp-h
 aclocal
-libtoolize -f   || glibtoolize -f
+LIBTOOLIZE=glibtoolize
+if test `which libtoolize`x != "x" ; 
+  then LIBTOOLIZE=libtoolize 
+fi
+$LIBTOOLIZE  -f
 autoheader -f
 autoconf -f
 automake --add-missing -c
