@@ -90,7 +90,7 @@ int	aff_toc_build(AFFILE *af)	// build the dir if we couldn't find it
     while(1){
 	char segname[AF_MAX_NAME_LEN];
 	size_t segname_len=sizeof(segname);
-	off_t pos = ftello(af->aseg);
+	uint64_t pos = ftello(af->aseg);
 	size_t datalen=0;
 
 	int r = af_get_next_seg(af,segname,segname_len,0,0,&datalen);
