@@ -52,7 +52,6 @@
 #include "vnode_afm.h"
 #include "vnode_aff.h"
 #include "vnode_afd.h"
-#include "vnode_ewf.h"
 
 #ifdef USE_QEMU
 #include "vnode_qemu.h"
@@ -79,9 +78,6 @@ struct af_vnode *af_vnode_array[] = {
     &vnode_afd, 
     &vnode_afm,				// must be before aff
     &vnode_aff,
-#ifdef USE_LIBEWF
-    &vnode_ewf,				// libewf
-#endif
 #ifdef USE_QEMU
     &vnode_vmdk,
     &vnode_dmg,
@@ -355,7 +351,7 @@ AFFILE *af_open_with(const char *url,int flags,int mode, struct af_vnode *v)
     }
 
     /* Set up the encryption if requested and if this support metadata */
-    if(AF_SEALING_VNODE(af)){
+    if(AF_SEALING_VNODE(af) && ((flags & AF_NO_CRYPTO)==0)){
 	bool can_decrypt = false;
 	if(af->password){
 	    struct af_vnode_info vni;
@@ -396,6 +392,10 @@ AFFILE *af_open_with(const char *url,int flags,int mode, struct af_vnode *v)
 AFFILE *af_open(const char *filename,int flags,int mode)
 {
     if(!aff_initialized) af_initialize();
+    if(ends_with(filename,".E01") || ends_with(filename,".e01")){
+	return 0;
+    }
+
     if(flags & O_WRONLY){
 	errno = EINVAL;
 	return 0;			// this flag not supported
@@ -556,7 +556,7 @@ int af_eof(AFFILE *af)
 	errno = EINVAL;
 	return -1;		// this is bad
     }
-    int ret = ((int64_t)af->pos >= vni.imagesize);
+    int ret = (int64_t)af->pos >= (int64_t)vni.imagesize;
     AF_UNLOCK(af);
     return ret;
 }
@@ -631,7 +631,7 @@ int64_t af_get_imagesize(AFFILE *af)
  */
 int af_make_badflag(AFFILE *af)
 {
-#ifdef HAVE_OPENSSL_RAND_H
+#ifdef HAVE_RAND_pseudo_bytes
     /* Use a good random number generator if we have it */
     RAND_pseudo_bytes(af->badflag,af->image_sectorsize);
     strcpy((char *)af->badflag,"BAD SECTOR");
@@ -678,8 +678,6 @@ int af_make_gid(AFFILE *af)
 
 
 
-/*TK: Here for locking */
-
 /* Decrypt data and perform unblocking if necessary.
  * This could eliminate a memory copy by doing the decryption for everything
  * but the last block in place, and just doing a copy for the last block.
