@@ -5,13 +5,16 @@
  * afflib.h:
  * 
  * This file describes the public AFFLIB interface.
- * The interface to reading AFF files, Raw files, and EnCase file (if libewf is compiled in).
+ * The interface to reading AFF files and  Raw files.
  */
 
 /* Figure out what kind of OS we are running on */
 
 /* These are both needed; no need to bother with affconfig.h #defines */
 #include <stdio.h>
+#ifdef HAVE_STDINT_H
+#include <stdint.h>
+#endif
 #include <sys/types.h>
 
 #ifdef HAVE_SYS_CDEFS_H
@@ -33,24 +36,21 @@
 
 /** WIN32 is defined by the NMAKE makefile for Visual C++ under Windows and by mingw **/
 #ifdef WIN32                            
+#include <basetsd.h>
 #include <io.h>				// gets isatty
-typedef unsigned int uint;
-typedef unsigned int u_int;
-typedef unsigned long ulong;
-typedef unsigned long u_long;
-typedef unsigned __int64 uint64;		/* 64-bit types Types */
-typedef          __int64 int64;
-typedef unsigned char u_char;
 
+/* These aren't needed for mingw */
+#if !defined(__MINGW_H)
 #ifndef _UINT64_T_DECLARED
 typedef unsigned __int64 uint64_t;	/* 64-bit types Types */
 #define _UINT64_T_DECLARED
 #endif
 
 #ifndef _INT64_T_DECLARED
-typedef         __int64 int64_t;
+typedef __int64 int64_t;
 #define _INT64_T_DECLARED
 #endif
+#endif
 
 #ifndef PRId64
 #define PRId64 "I64d"
@@ -64,14 +64,9 @@ typedef         __int64 int64_t;
 #define PRIu64 "I64u"
 #endif
 
-//int64   ftello(FILE *stream);	 /* Functions that Microsoft forgot */
-//int     fseeko(FILE *stream,int64 offset,int whence);
-#define ftello ftello64
-#define fseeko fseeko64
-#endif
+#endif	
 /** END OF WIN32 DEFINES **/
 
-
 #define I64d PRIi64
 #define I64u PRIu64
 
@@ -90,7 +85,7 @@ struct aff_pagebuf {
 };
 
 struct af_vnode_info {
-    int64_t imagesize;			// size of this image
+    uint64_t imagesize;			// size of this image
     int   pagesize;			// what is the natural page size?
     u_int supports_compression:1; // supports writing compressed segments
     u_int has_pages:1;		 // does system support page segments?
@@ -141,7 +136,7 @@ extern "C" {
  ***
  ****************************************************************/
 
-const char *af_version(void);		// returns AFF Version Number
+const char * af_version(void);		// returns AFF Version Number
 
 /* af_file stream functions */
 AFFILE *af_open(const char *filename,int flags,int mode);
@@ -175,12 +170,17 @@ int	af_set_option(AFFILE *af,int option,int value);
 #define AF_OPEN_PRIMITIVE (1<<31)	// only open primtive, not compound files
 #define AF_BADBLOCK_FILL  (1<<30)	// fill unallocated (sparse) with BADBLOCK flag
 #define AF_HALF_OPEN      (1<<29)       // return af before calling af->v->open; 
+#define AF_NO_CRYPTO      (1<<28)       // disable encryption layer
 
 /* navigating within the data segments as if they were a single file */
-ssize_t	af_read(AFFILE *af,unsigned char *buf,ssize_t count);
+#ifdef _WIN32
+SSIZE_T af_read(AFFILE *af,unsigned char *buf,SSIZE_T count);
+#else
+ssize_t af_read(AFFILE *af,unsigned char *buf,ssize_t count);
+#endif
 uint64_t  af_seek(AFFILE *af,int64_t pos,int whence); // returns new position
 uint64_t  af_tell(AFFILE *af);
-int	af_eof(AFFILE *af);		// is the virtual file at the end?
+int	  af_eof(AFFILE *af);		// is the virtual file at the end?
 
 /* Additional routines for writing */
 void	af_set_callback(AFFILE *af, void (*cb)(struct affcallback_info *acbi)); 
