@@ -48,6 +48,17 @@
 #ifndef AFFLIB_I_H
 #define AFFLIB_I_H
 
+#ifdef KERNEL_LIBRARY
+#ifdef __cplusplus
+extern "C" {
+#endif
+void __cdecl AFDbgPrint (PCSTR Format,...);
+#ifdef __cplusplus
+}
+#endif
+#endif
+
+
 /* Should we disable threading? */
 #ifdef DISABLE_PTHREAD
 #undef HAVE_PTHREAD
@@ -115,7 +126,9 @@
 #endif
 
 #ifdef WIN32
+#if !defined(__MINGW_H)
 #pragma warning(disable: 4996)  /* Don't warn on Windows about using POSIX open() instead of _open() */
+#endif
 #include <malloc.h>
 #include <windows.h>
 #include <winsock.h>			// htonl()
@@ -123,11 +136,23 @@
 #define snprintf _snprintf
 #define strcasecmp _stricmp
 #define mkdir(path,mode) _mkdir(path)
-#define ENOTSUP 65536		/* made up number */
 #define random() rand()
 #define access _access
 #define strdup _strdup
 
+#ifndef ENOTSUP
+#define ENOTSUP 65536		/* made up number */
+#endif
+
+typedef unsigned int uint;
+typedef unsigned int u_int;
+typedef unsigned long ulong;
+typedef unsigned long u_long;
+typedef unsigned __int64 uint64;		/* 64-bit types Types */
+typedef __int64 int64;
+typedef unsigned char u_char;
+
+
 #ifndef _MODE_T_
 #define _MODE_T_
 typedef unsigned short mode_t;
@@ -144,6 +169,21 @@ typedef unsigned int uint32_t ;
 #define ftruncate(fd,size) _chsize_s(fd,size)
 #define MAXPATHLEN 1024
 #endif
+
+#if defined(__MINGW_H)
+#ifndef ftello
+#define ftello ftello64
+#endif
+
+#ifndef fseeko
+#define fseeko fseeko64
+#endif
+
+#else
+#define ftello _ftelli64			/* replaces ftello64 in VC2008 */
+#define fseeko _fseeki64
+#endif
+
 #endif
 /** END OF WIN32 DEFINES **/
 
@@ -319,8 +359,7 @@ struct _AFFILE {
     struct aff_pagebuf *pbcache;	// array of pagebufs
     int		num_pbufs;	   // number of pagebufs; default is 1
     int		afftime;		// for updating last
-    int64_t	cur_page;		// used by vnode_raw and vnode_ewf to fake pages
-					// must be able to go negative
+    int64_t	cur_page;		// used by vnode_raw to fake pages must be able to go negative.
 
     int		  debug;		// for debugging, of course
     unsigned int  badflag_set:1;	// is badflag set?
@@ -516,7 +555,7 @@ const char *af_identify_file_name(const char *filename,int exists); // returns n
 #define AF_IDENTIFY_EVD 4		// file is a .E01 file when there are more files following
 #define AF_IDENTIFY_SPLIT_RAW 5		// file is a split raw file
 #define AF_IDENTIFY_AFM 6               // file is raw file with metadata
-#define AF_IDENTIFY_EWF 7		// libewf
+#define AF_IDENTIFY_EWF 7		// libewf; deprecated
 #define AF_IDENTIFY_S3  8		// is an s3:/// file
 #define AF_IDENTIFY_VMDK 9		// QEMU support for VMDK format
 #define AF_IDENTIFY_DMG 10		// QEMU support for Apple DMG format
@@ -594,12 +633,13 @@ int	af_get_seg(AFFILE *af,const char *name,unsigned long *arg,
  * Note: pagename to string translation happens inside afflib.cpp, not inside
  * the vnode driver. 
  */
+#define af_page_size(af) (af_get_pagesize(af)) /* backwards compatability */
 void	af_read_sizes(AFFILE *af);	// sets up values if we can get them.
 int	af_set_pagesize(AFFILE *af,u_long pagesize); // sets the pagesize; fails with -1 if imagesize >=0
 int	af_set_sectorsize(AFFILE *AF,int sectorsize); // fails with -1 if imagesize>=0
 int	af_get_sectorsize(AFFILE *AF);	// returns sector size
 int	af_has_pages(AFFILE *af);	// does the underlying system support pages?
-int	af_page_size(AFFILE *af);	// returns page size, or -1
+int	af_get_pagesize(AFFILE *af);	// returns page size, or -1
 int	af_get_page_raw(AFFILE *af,int64_t pagenum,unsigned long *arg,u_char *data,size_t *bytes);
 int	af_get_page(AFFILE *af,int64_t pagenum,u_char *data,size_t *bytes);
 #define AF_SIGFLAG_NOSIG 0x0001	// do not write signatures with af_update_segf()
@@ -660,7 +700,6 @@ size_t strlcat(char *dest,const char *src,size_t dest_size);
 int	aff_segment_overhead(const char *segname);	
 int	aff_toc_free(AFFILE *af);
 void	aff_toc_print(AFFILE *af);
-//int	aff_toc_append(AFFILE *af,const char *segname,int64_t offset);
 int	aff_toc_build(AFFILE *af);	// build by scanning the AFFILE
 struct aff_toc_mem *aff_toc(AFFILE *af,const char *segname);
 int	aff_toc_del(AFFILE *af,const char *segname);
