@@ -32,6 +32,8 @@
  *** Extra code for Windows...
  ****************************************************************/
 
+/* No longer needed with VC2008 */
+#if 0					
 #if defined(WIN32) and !defined(__MINGW_H)
 #pragma warning(disable: 4996)
 int64 ftello(FILE *stream)
@@ -61,6 +63,7 @@ int fseeko(FILE *stream,int64 offset,int whence)
     return fsetpos(stream,&offset);
 }
 #endif
+#endif
 
 
 
