@@ -220,12 +220,14 @@ int af_get_page(AFFILE *af,int64_t pagenum,unsigned char *data,size_t *bytes)
 	return r;		// segment doesn't exist
     }
        
-    /* If no data buffer was provided, just return */
-    if(data==0) return 0;
 
     /* If the segment isn't compressed, just get it*/
     unsigned long pageflag = 0;
     if((arg & AF_PAGE_COMPRESSED)==0){
+	if(data==0){			// if no data provided, just return size of the segment if requested
+	    if(bytes) *bytes = page_len;	// set the number of bytes in the page if requested
+	    return 0;
+	}
 	int ret = af_get_page_raw(af,pagenum,&pageflag,data,bytes);
 	if(*bytes > page_len) *bytes = page_len; // we only read this much
 	if(ret!=0) return ret;		// some error happened?
@@ -244,8 +246,16 @@ int af_get_page(AFFILE *af,int64_t pagenum,unsigned char *data,size_t *bytes)
 	    return -3;			// read error
 	}
 
-	/* Now uncompress directly into the buffer provided by the caller. */
+	/* Now uncompress directly into the buffer provided by the caller, unless the caller didn't
+	 * provide a buffer. If that happens, allocate our own...
+	 */
 	int res = -1;			// 0 is success
+	bool free_data = false;
+	if(data==0){
+	    data = (unsigned char *)malloc(af->image_pagesize);
+	    free_data = true;
+	    *bytes = af->image_pagesize; // I can hold this much
+	}
 
 	switch((pageflag & AF_PAGE_COMP_ALG_MASK)){
 	case AF_PAGE_COMP_ALG_ZERO:
@@ -301,6 +311,10 @@ int af_get_page(AFFILE *af,int64_t pagenum,unsigned char *data,size_t *bytes)
 	    break;
 	}
 
+	if(free_data){
+	    free(data);
+	    data = 0;			// restore the way it was
+	}
 	free(compressed_data);		// don't need this one anymore
 	af->pages_decompressed++;
 	if(res!=Z_OK) return -1;
@@ -310,7 +324,7 @@ int af_get_page(AFFILE *af,int64_t pagenum,unsigned char *data,size_t *bytes)
      * make sure that the rest of the sector is zeroed, and that the
      * rest after that has the 'bad block' notation.
      */
-    if(af->image_pagesize > af->image_sectorsize){
+    if(data && (af->image_pagesize > af->image_sectorsize)){
 	const int SECTOR_SIZE = af->image_sectorsize;	// for ease of typing
 	size_t bytes_left_in_sector = (SECTOR_SIZE - (*bytes % SECTOR_SIZE)) % SECTOR_SIZE;
 	for(size_t i=0;i<bytes_left_in_sector;i++){
@@ -524,12 +538,6 @@ int af_update_page(AFFILE *af,int64_t pagenum,unsigned char *data,int datalen)
  * af_cache_writethrough(af,page,buf,buflen)
  *      - used for write bypass
  *
- * af_cache_load(af,page) - 
- *      - If page is already in the cache, return it.
- *      - If cache is filled, randomly discard a page
- *      - if page is on the disk, load the page.
- *      - Sets af->bp to be the page that was loaded.
- *
  */
 
 static int cachetime = 0;
