@@ -9,10 +9,6 @@
 #include "base64.h"
 #include "aftimer.h"
 
-#ifdef HAVE_THREADED_HASH_H
-#include "threaded_hash.h"
-#endif
-
 #ifdef HAVE_GETOPT_H
 #include <getopt.h>
 #endif
@@ -720,44 +716,6 @@ void xmltest(const char *fn);
 
 void time_test()
 {
-#ifdef HAVE_THREADED_HASH_H
-    int size = 1024*1024*256;
-    unsigned char *buf1 = (u_char *)calloc(size,1);
-    int threaded=0;
-
-    printf("sha1 is 3b4417fc421cee30a9ad0fd9319220a8dae32da2\n");
-    for(int count=0;count<2;count++){
-	buf1[0]= count;
-	for(threaded=0;threaded<2;threaded++){
-	    aftimer t;
-	    threaded_hash h_md5(EVP_get_digestbyname("md5"),threaded);
-	    threaded_hash h_sha1(EVP_get_digestbyname("sha1"),threaded);
-	    threaded_hash h_sha2(EVP_get_digestbyname("sha1"),threaded);
-	    threaded_hash h_sha3(EVP_get_digestbyname("sha1"),threaded);
-	    threaded_hash h_sha256(EVP_get_digestbyname("sha256"),threaded);
-	    
-	    printf("Threaded: %d size: %d\n",threaded,size);
-	    t.start();
-	    h_sha1.update(buf1,size);
-	    h_sha2.update(buf1,size);
-	    h_sha3.update(buf1,size);
-	    h_md5.update(buf1,size);
-	    h_sha256.update(buf1,size);
-	    
-	    unsigned char md[32];
-	    char b[64];
-
-	    h_md5.final(md,sizeof(md)); printf("md5: %s\n",af_hexbuf(b,sizeof(b),md,16,0));
-	    h_sha1.final(md,sizeof(md)); printf("sha1: %s\n",af_hexbuf(b,sizeof(b),md,20,0));
-	    h_sha2.final(md,sizeof(md)); printf("sha2: %s\n",af_hexbuf(b,sizeof(b),md,20,0));
-	    h_sha3.final(md,sizeof(md)); printf("sha3: %s\n",af_hexbuf(b,sizeof(b),md,20,0));
-	    h_sha256.final(md,sizeof(md)); printf("sha256: %s\n",af_hexbuf(b,sizeof(b),md,32,0));
-	    t.stop();
-	    printf("time: %g\n",t.elapsed_seconds());
-	    printf("==============================\n");
-	}
-    }
-#endif
     exit(0);
 }
 
@@ -891,6 +849,7 @@ void usage()
     printf("    -n nn = sets MAX_FMTS (default %d)\n",MAX_FMTS);
     printf("    -i image write speed test (lots of small pages)\n");
     printf("    -v = verbose\n");
+    printf("    -S filename = perform split-raw tests on filename\n");
 #ifdef HAVE_AES_ENCRYPT
     printf("    -C = just test AES encryption\n");
 #endif
@@ -898,6 +857,16 @@ void usage()
     printf("    -z fn = open up fn for writing and zap it.\n");
 }
 
+int split_raw_test(const char *fn)
+{
+    void srp_dump(AFFILE *af);
+    AFFILE *af = af_open(fn,O_RDONLY,0666);
+    printf("split_raw imagesize: %"PRId64"\n",af_get_imagesize(af));
+    srp_dump(af);
+    af_close(af);
+    return 0;
+}
+
 int main(int argc,char **argv)
 {
     progname = argv[0];
@@ -926,7 +895,7 @@ int main(int argc,char **argv)
 	do_all = 1;
     }
 
-    while ((ch = getopt(argc, argv, "b123456aBLd:h?f:e:c:TCp:rx:R:z:tn:D:")) != -1) {
+    while ((ch = getopt(argc, argv, "b123456aBLd:h?f:e:c:TCp:rx:R:z:tn:D:S:")) != -1) {
 	switch(ch){
 	case 'D': af_trace = fopen(optarg,"w");break;
 	case 'R': readfile_test(optarg); break;
@@ -974,6 +943,7 @@ int main(int argc,char **argv)
 	case 'x': xmltest(optarg);break;
 	case 'C': aestest(); break;
 	case 'i': do_image_test=1;break;
+	case 'S': split_raw_test(optarg);exit(0);
 	case 'h':
 	case '?':
 	default:
