@@ -48,16 +48,18 @@
 #include <openssl/bio.h>
 #endif
 
+#ifdef HAVE_STL
 #include <vector>
 #include <set>
 #include <string>
+using namespace std;
+#endif
 
 #ifdef HAVE_CSTRING
 #include <cstring>
 #endif
 
 
-using namespace std;
 
 
 
@@ -341,6 +343,7 @@ int  af_establish_aes_passphrase(AFFILE *af,const char *passphrase)
  */
 int  af_use_aes_passphrase(AFFILE *af,const char *passphrase)
 {
+    af_invalidate_vni_cache(af);
     if(passphrase==0 && !(af->openflags & O_RDWR)){
 	af->crypto->sealing_key_set = 0;
 	return 0;
@@ -563,6 +566,7 @@ int af_sign_seg(AFFILE *af,const char *segname)
 }
 
 
+#ifdef HAVE_STL
 /** Returns number of segments that were signed.
  * Returns -1 if there is an error.
  */
@@ -600,6 +604,7 @@ int af_sign_all_unsigned_segments(AFFILE *af)
     }
     return count;
 }
+#endif
 
 /* Verify a segment against a particular signature and public key */
 int af_hash_verify_seg2(AFFILE *af,const char *segname,u_char *sigbuf_,size_t sigbuf_len_,int sigmode)
