@@ -24,6 +24,9 @@ static int	aff_write_seg(AFFILE *af,const char *name,unsigned long arg,
 			      const u_char *value,size_t vallen); 
 static int	aff_get_seg(AFFILE *af,const char *name,unsigned long *arg,
 			    unsigned char *data,size_t *datalen);
+#ifdef KERNEL_LIBRARY
+static int	aff_write_seg_no_data(AFFILE *af,const char *name,unsigned long arg, size_t vallen); 
+#endif
 static int	aff_get_next_seg(AFFILE *af,char *segname,size_t segname_len,
 				 unsigned long *arg, unsigned char *data, size_t *datalen);
 
@@ -39,10 +42,14 @@ int aff_segment_overhead(const char *segname)
 
 static int aff_write_ignore2(AFFILE *af,size_t bytes)
 {
+#ifdef KERNEL_LIBRARY
+    aff_write_seg_no_data(af,AF_IGNORE,0,bytes);
+#else
     if(af_trace) fprintf(af_trace,"aff_write_ignore2(%p,%zd)\n",af,bytes);
     unsigned char *invalidate_data = (unsigned char *)calloc(bytes,1);
     aff_write_seg(af,AF_IGNORE,0,invalidate_data,bytes); // overwrite with NULLs
     free(invalidate_data);
+#endif
     return 0;
 }
 
@@ -144,6 +151,51 @@ int aff_write_seg(AFFILE *af, const char *segname,unsigned long arg,const u_char
 }
 
 
+#ifdef KERNEL_LIBRARY
+/* aff_write_seg_no_data:
+ * put the given named segment at the current position in the file but don't write any data.
+ * <km> this is an attempt at optimizing the write performance
+ * Return 0 for success, -1 for failure (probably disk full?)
+ */
+
+int aff_write_seg_no_data(AFFILE *af, const char *segname,unsigned long arg,size_t datalen)
+{
+    struct af_segment_head segh;
+    struct af_segment_tail segt;
+
+    assert(sizeof(segh)==16);
+    assert(sizeof(segt)==8);
+
+    /* If the last command was not a probe (so we know where we are), and
+     * we are not at the end of the file, something is very wrong.
+     */
+
+    unsigned int segname_len = strlen(segname);
+
+    strcpy(segh.magic,AF_SEGHEAD);
+    segh.name_len = htonl(segname_len);
+    segh.data_len = htonl(datalen);
+    segh.flag      = htonl(arg);
+
+    strcpy(segt.magic,AF_SEGTAIL);
+    segt.segment_len = htonl(sizeof(segh)+segname_len + datalen + sizeof(segt));
+    aff_toc_update(af,segname,ftello(af->aseg),datalen);
+
+    
+    if(af_trace) fprintf(af_trace,"aff_write_seg: putting segment %s (datalen=%zd) offset=%"PRId64"\n",
+			 segname,datalen,ftello(af->aseg));
+
+    if(fwrite(&segh,sizeof(segh),1,af->aseg)!=1) return -10;
+    if(fwrite(segname,1,segname_len,af->aseg)!=segname_len) return -11;
+    //if(fwrite(data,1,datalen,af->aseg)!=datalen) return -12;
+    if(fseeko(af->aseg,datalen,SEEK_CUR)!=0) return -12;
+    if(fwrite(&segt,sizeof(segt),1,af->aseg)!=1) return -13;
+    fflush(af->aseg);			// make sure it is on the disk
+    return 0;
+}
+#endif
+
+
 /****************************************************************
  *** low-level routines for reading 
  ****************************************************************/
@@ -168,7 +220,7 @@ static int aff_get_seg(AFFILE *af,const char *name,
 
     fseeko(af->aseg,adm->offset,SEEK_SET);
     int ret = aff_get_next_seg(af,next,sizeof(next),arg,data,datalen);
-    assert(strcmp(next,name)==0);	// hopefully this is what they asked for
+    assert(ret!=0 || strcmp(next,name)==0);	// hopefully this is what they asked for
     return ret;
 }
 
@@ -198,7 +250,7 @@ static int aff_get_next_seg(AFFILE *af,char *segname,size_t segname_len,unsigned
 	return AF_ERROR_INVALID_ARG;
     }
 
-    off_t start = ftello(af->aseg);
+    uint64_t start = ftello(af->aseg);
     size_t data_len;
 
     int r = af_probe_next_seg(af,segname,segname_len,arg,&data_len,0,0);
