@@ -50,7 +50,11 @@ static int qemu_open(AFFILE *af)
 	bdrv_init_called = 1;
     }
     bs = bdrv_new("");
-    bdrv_open2(bs,af_filename(af),0,drv);
+    if (bs == NULL) return -1;
+    if(bdrv_open2(bs,af_filename(af),0,drv)!=0){
+	bdrv_delete(bs);
+	return -1;
+    }
     bdrv_get_geometry(bs, &total_sectors);
 
     af->image_pagesize   = 1024*1024*1;	// megabyte for now
