@@ -156,6 +156,8 @@ void srp_validate(AFFILE *af)
     }
 }    
 
+/** Debugging routine.
+ */
 void srp_dump(AFFILE *af)
 {
     struct split_raw_private *srp = SPLIT_RAW_PRIVATE(af);
@@ -183,7 +185,7 @@ static int split_raw_open_internal(AFFILE *af, uint64_t *image_size)
     int fd;
     struct stat sb;
 
-    fd = open(srp->first_raw_fname, af->openflags|O_BINARY, 0666);
+    fd = open(srp->first_raw_fname, af->openflags|O_BINARY, af->openmode);
     if (fd < 0) {
       (*af->error_reporter)("split_raw_open_internal: open(%s): ",af->fname);
 	return -1;
@@ -216,7 +218,7 @@ static int split_raw_open_internal(AFFILE *af, uint64_t *image_size)
 
     do {
 	if (increment_fname (srp->next_raw_fname) != 0) {
-	    fprintf (stderr, "split_raw_open_internal: too many files\n");
+	    (*af->error_reporter)("split_raw_open_internal: too many files\n");
 	    errno = EINVAL;
 	    return -1;
 	}
@@ -234,9 +236,8 @@ static int split_raw_open_internal(AFFILE *af, uint64_t *image_size)
 	}
 	srp_add_fd(af,fd);
 	if (current_file_must_be_last) {
-	    fprintf(stderr,
-		    "split_raw_open_internal: %s exists, "
-		    "but previous file didn't match expected file size\n",af->fname);
+	    (*af->error_reporter)("split_raw_open_internal: %s exists, "
+				  "but previous file didn't match expected file size\n",af->fname);
 	    return -1;
 	}
 	/* Set af->maxsize to the size of the first file, but only
@@ -279,9 +280,8 @@ static int split_raw_open(AFFILE *af)
 	af->image_pagesize *= 2;
 
     if ((ret == 0) && (af->maxsize % af->image_pagesize!=0)) {
-	fprintf (stderr,
-		 "split_raw_open: %s: raw_file_size (%"I64d" not a multiple of pagesize %lu\n",
-		 af->fname, af->maxsize,af->image_pagesize);
+	(*af->error_reporter)("split_raw_open: %s: raw_file_size (%"I64d" not a multiple of pagesize %lu\n",
+			      af->fname, af->maxsize,af->image_pagesize);
 	split_raw_close (af);
 	return -1;
     }
@@ -375,7 +375,7 @@ int split_raw_write_internal2(AFFILE *af, unsigned char *buf, uint64_t pos,size_
 	if (af->maxsize) {	// do we need to possibly split into multiple file writes?
 	    /* Figure out which file number we will need to write to... */
 	    if (pos >= (af->maxsize * srp->num_raw_files)) {
-		int fd = open(srp->next_raw_fname, O_RDWR | O_CREAT | O_EXCL | O_BINARY, 0666);
+		int fd = open(srp->next_raw_fname, O_RDWR | O_CREAT | O_EXCL | O_BINARY, af->openmode);
 		if (fd < 0) {
 		  (*af->error_reporter)("split_raw_write: open(%s): ",af->fname);
 		    if (ret) return ret;
@@ -488,6 +488,38 @@ static int split_raw_get_seg(AFFILE *af,const char *name,unsigned long *arg,unsi
 {
     int64_t page_num = af_segname_page_number(name);
     if(page_num<0){
+	/* See if PAGESIZE or IMAGESIZE is being requested; we can fake those */
+	if(strcmp(name,AF_PAGESIZE)==0){
+	    if(arg) *arg = af->image_pagesize;
+	    if(datalen) *datalen = 0;
+	    return 0;
+	}
+	if(strcmp(name,AF_IMAGESIZE)==0){
+	    struct aff_quad q;
+	    if(data && *datalen>=8){
+		q.low = htonl((unsigned long)(af->image_size & 0xffffffff));
+		q.high = htonl((unsigned long)(af->image_size >> 32));
+		memcpy(data,&q,8);
+		*datalen = 8;
+	    }
+	    return 0;
+	}
+	if(strcmp(name,AF_SECTORSIZE)==0){
+	    if(arg) *arg = af->image_sectorsize;
+	    if(datalen) *datalen = 0;
+	    return 0;
+	}
+	if(strcmp(name,AF_DEVICE_SECTORS)==0){
+	    int64_t devicesectors = af->image_size / af->image_sectorsize;
+	    struct aff_quad q;
+	    if(data && *datalen>=8){
+		q.low = htonl((unsigned long)(devicesectors & 0xffffffff));
+		q.high = htonl((unsigned long)(devicesectors >> 32));
+		memcpy(data,&q,8);
+		*datalen = 8;
+	    }
+	    return 0;
+	}
 	errno = ENOTSUP;		// sorry! We don't store metadata
 	return -1;
     }
