@@ -17,13 +17,13 @@ def runtest(ext,maxsize):
     cmd("rm -rf %s %s %s %s" % (iso,iso2,i1,i2))
     cmd("./makeimage %s 100000",(iso))
     cmd("../aimage/aimage   %s -q -E %s %s" % (maxsize,iso,i1))
-    cmd("../tools/afconvert %s -o %s %s" % (maxsize,i2,iso))
-    cmd("../tools/afinfo -mS %s" % (i1))
-    cmd("../tools/afinfo -mS %s" % (i2))
-    cmd("../tools/afcompare %s %s" % (iso,i1))
-    cmd("../tools/afcompare %s %s" % (iso,i2))
-    cmd("../tools/afconvert -r -o %s %s" % (iso,i1))
-    cmd("../tools/afcat %s > %s" % (i2,iso2))
+    cmd("../tools/affconvert %s -o %s %s" % (maxsize,i2,iso))
+    cmd("../tools/affinfo -mS %s" % (i1))
+    cmd("../tools/affinfo -mS %s" % (i2))
+    cmd("../tools/affcompare %s %s" % (iso,i1))
+    cmd("../tools/affcompare %s %s" % (iso,i2))
+    cmd("../tools/affconvert -r -o %s %s" % (iso,i1))
+    cmd("../tools/affcat %s > %s" % (i2,iso2))
     cmd("cmp %s %s" % (iso,iso2))
     cmd("rm -rf %s %s %s %s" % (iso,iso2,i1,i2))
 
