@@ -9,12 +9,12 @@ unset AFFLIB_PASSPHRASE
 echo === Putting a new metadata segment into blank.aff  ===
 
 /bin/rm -f $BLANK_AFF
-afcopy /dev/null $BLANK_AFF
-afsegment -ssegname=testseg1 $BLANK_AFF
-if [ x"testseg1" = x`afsegment -p segname $BLANK_AFF` ] ; then 
-  echo afsegment worked!
+affcopy /dev/null $BLANK_AFF
+affsegment -ssegname=testseg1 $BLANK_AFF
+if [ x"testseg1" = x`affsegment -p segname $BLANK_AFF` ] ; then 
+  echo affsegment worked!
 else
-  echo afsegment does not work properly
+  echo affsegment does not work properly
   exit 1
 fi
 /bin/rm -f $BLANK_AFF
