@@ -9,11 +9,13 @@ AGENT_PEM=$BASE.agent.pem
 ANALYST_PEM=$BASE.analyst.pem
 ARCHIVES_PEM=$BASE.archives.pem
 EVIDENCE=$BASE.evidence.aff
+EVIDENCE1=$BASE.evidence1.aff
 EVIDENCE2=$BASE.evidence2.aff
 EVIDENCE3=$BASE.evidence3.aff
 
 /bin/rm -f $AGENT_PEM $ANALYST_PEM $ARCHIVES_PEM $EVIDENCE $EVIDENCE2 $EVIDENCE3
 
+echo TEST $0
 echo === MAKING THE TEST FILES ===
 
 export PATH=$srcdir:../tools:../../tools:.:$PATH
@@ -30,40 +32,42 @@ openssl req -x509 -newkey rsa:1024 -keyout $ARCHIVES_PEM -out $ARCHIVES_PEM -nod
 
 echo Making an AFF file to sign
 rm -f $EVIDENCE evidence?.aff
-afconvert -o $EVIDENCE rawevidence.iso 
+affconvert -o $EVIDENCE rawevidence.iso 
 echo Initial AFF file
-if ! afinfo -a $EVIDENCE ; then exit 1 ; fi
+if ! affinfo -a $EVIDENCE ; then exit 1 ; fi
 
 echo Signing AFF file...
-echo afsign -k $AGENT_PEM $EVIDENCE 
-if ! afsign -k $AGENT_PEM $EVIDENCE ; then echo afsign failed ; exit 1 ; fi 
+echo affsign -k $AGENT_PEM $EVIDENCE 
+if ! affsign -k $AGENT_PEM $EVIDENCE ; then echo affsign failed ; exit 1 ; fi 
 
 echo Verifying Signature...
-echo afverify $EVIDENCE 
-if ! afverify $EVIDENCE ; then echo afverify failed ; exit 1 ; fi ; 
+echo affverify $EVIDENCE 
+if ! affverify $EVIDENCE ; then echo affverify failed ; exit 1 ; fi ; 
 
 echo Signature test 1 passed
-
 echo Testing chain-of-custody signatures
-echo Copying original raw file to evidence1.aff
 
-if ! afcopy -z -k $AGENT_PEM rawevidence.iso evidence1.aff ; then exit 1; fi
-if ! afinfo -a evidence1.aff ; then exit 1 ; fi
-if ! afcompare rawevidence.iso evidence1.aff ; then exit 1 ; fi
-if ! afverify evidence1.aff ; then exit 1 ; fi
+echo Step 10: Copying original raw file to evidence1.aff
+if ! affcopy -k $AGENT_PEM rawevidence.iso evidence1.aff ; then exit 1; fi
+echo Step 11: Running affinfo on evidence1.aff
+if ! affinfo -a evidence1.aff ; then exit 1 ; fi
+echo Step 12: Comparing rawevidence.iso to evidence1.aff
+if ! affcompare rawevidence.iso evidence1.aff ; then exit 1 ; fi
+echo Step 13: Verifying evidence1
+if ! affverify evidence1.aff ; then exit 1 ; fi
 
 echo
 echo Making the second generation copy
-echo "This copy was made by the analyst" | afcopy -z -k $ANALYST_PEM -n evidence1.aff $EVIDENCE2
-if ! afinfo -a $EVIDENCE2 ; then exit 1 ; fi
-if ! afcompare rawevidence.iso $EVIDENCE2 ; then exit 1 ; fi
-if ! afverify $EVIDENCE2 ; then exit 1 ; fi
+echo "This copy was made by the analyst" | affcopy -z -k $ANALYST_PEM -n evidence1.aff $EVIDENCE2
+if ! affinfo -a $EVIDENCE2 ; then exit 1 ; fi
+if ! affcompare rawevidence.iso $EVIDENCE2 ; then exit 1 ; fi
+if ! affverify $EVIDENCE2 ; then exit 1 ; fi
 echo
 echo Making the third generation copy
-echo "This copy was made by the archives" | afcopy -z -k $ARCHIVES_PEM -n $EVIDENCE2 $EVIDENCE3
-if ! afinfo -a $EVIDENCE3 ; then exit 1 ; fi
-if ! afcompare rawevidence.iso $EVIDENCE3 ; then exit 1 ; fi
-if ! afverify $EVIDENCE3 ; then exit 1 ; fi
+echo "This copy was made by the archives" | affcopy -z -k $ARCHIVES_PEM -n $EVIDENCE2 $EVIDENCE3
+if ! affinfo -a $EVIDENCE3 ; then exit 1 ; fi
+if ! affcompare rawevidence.iso $EVIDENCE3 ; then exit 1 ; fi
+if ! affverify $EVIDENCE3 ; then exit 1 ; fi
 
 
 echo All tests passed successfully
